<?php

namespace App\Http\Controllers;

use App\Mail\ContactMessages;
use App\Models\Contactus;
use App\Models\Orders;
use App\Models\Record;
use App\Models\Setting;
use App\Models\StripeCustomer;
use App\Models\Subscription;
use App\Models\User;
use Cassandra\Set;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Auth;
use mysql_xdevapi\Collection;

class WebsiteController extends Controller
{
    public function home(Request $request)
    {
        return view("website.home",compact('request'));
    }

    public function login()
    {
        if (Auth::check() && Auth::user()->type == "user") {
            return redirect()->route('/');

        } else {
            return view("website.login");
        }
    }

    public function forgot()
    {
        return view("website.forgot");
    }

    public function register()
    {
        if (Auth::check() && Auth::user()->type == "user") {
            return redirect()->route('/');

        } else {
            return view("website.register");
        }
    }

    public function profile()
    {
        $setting = Setting::first();
        return view('website.profile', compact('setting'));
    }

    public function history()
    {
        $subscription_history = Orders::where('userid', Auth::user()->id)->get();
        return view("website.history", compact('subscription_history'));
    }

    public function contact()
    {
        $setting = Setting::first();
        return view("website.contact", compact('setting'));
    }

    public function save_contact_message(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['subject'] = $request->subject;
        $data['message'] = $request->message;
        $contactdetail = Contactus::create($data);
        $maildata = Contactus::findOrFail($contactdetail->id);
        $setting = Setting::first();
        $maildata['logo'] = url('/admin/assets/uploads/' . $setting->logo);
        $check = Mail::to($setting->email)->send(new ContactMessages($maildata));
        if ($check) {
            return back()->with('success', 'Message Sent Successfully.');
        } else {
            return back()->with('error', 'Message Not Sent.');
        }
    }

    public function privacy()
    {
        return view("website.privacy");
    }

    public function terms()
    {
        return view("website.terms");
    }

    public function manage_records()
    {
        $subscription = Subscription::findOrFail(500);
        return view("website.record", compact('subscription'));
    }

    public static function check_available_records()
    {
        $total = Auth::user()->purchased_subscriptions_data->count();
        $total_added = Auth::user()->records_data->count();
        $available = $total - $total_added;
        if ($available == 0) {
            return 0;
        } else {
            return 1;
        }

    }

    public function manage_records_list()
    {
        $records = Record::where('userid', Auth::user()->id)->get();
        return view("website.manage_records_list", compact('records'));
    }

    public function save_record(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'phone' => 'required',
            'address' => 'required',
            'postal_code' => 'required',
            'state' => 'required',
            'city' => 'required',
            'mls_number' => 'required',
            'commission' => 'required',
            'type' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }

        if ($request->data_type == "save_subscription_data") {
            $check_credit = $this->check_available_records();
            if ($check_credit == 0) {
                return back()->withInput()->with('error', 'You dont have credit.Please purchase subscription.');
                dd("stop");
            }

            $data['userid'] = Auth::user()->id;
            $data['name'] = $request->name;
            $data['phone'] = $request->phone;
            $data['address'] = $request->address;
            $data['postal_code'] = $request->postal_code;
            $data['state'] = $request->state;
            $data['city'] = $request->city;
            $data['mls_number'] = $request->mls_number;
            $data['commission'] = $request->commission;
            $data['type'] = $request->type;
            $data['record_type'] = "subscription";
            $record = Record::create($data);
            if ($record) {
                return redirect()->route('manage_records_list')->with('success', 'Record Saved Successfully.');
            } else {
                return back()->withInput()->with('error', 'Record Not Saved.');
            }
        }

        if ($request->data_type == "save_without_subscription_data") {
            $data['userid'] = Auth::user()->id;
            $data['name'] = $request->name;
            $data['phone'] = $request->phone;
            $data['address'] = $request->address;
            $data['postal_code'] = $request->postal_code;
            $data['state'] = $request->state;
            $data['city'] = $request->city;
            $data['mls_number'] = $request->mls_number;
            $data['commission'] = $request->commission;
            $data['type'] = $request->type;
            $data['status'] = "0";
            $data['price'] = "";
            $data['payment_status'] = "unpaid";
            $data['record_type'] = "withoutsubscription";
            $record = Record::create($data);
            if ($record) {

                $subscription = Subscription::findOrFail(500);
                try {
                    $sk = Setting::first()->stripe_secret;
                    $stripe = new \Stripe\StripeClient($sk);
                    $customer = $stripe->customers->create([
                        'description' => "Purchase " . $subscription->heading . " Subscription",
                    ]);

                    $record->price = $subscription->price;
                    $record->update();

                    $session = $stripe->checkout->sessions->create([
                        'customer' => $customer,
                        'line_items' => [
                            [
                                'price_data' => [
                                    'currency' => 'usd',
                                    'product_data' => [
                                        'name' => 'Purchase ' . $subscription->heading . ' Subscription'
                                    ],
                                    'unit_amount' => $subscription->price * 100
                                ],
                                'quantity' => 1,
                            ],
                        ],
                        'mode' => 'payment',
                        'success_url' => url('/customsuccesspayment?session_id={CHECKOUT_SESSION_ID}&order_id=' . encrypt($record->id)),
                        'cancel_url' => route('subscription'),
                    ]);
                    return redirect()->away($session->url);
                } catch (Exception $e) {
                    return back()->withError($e->getMessage());
                }

            } else {
                return back()->withInput()->with('error', 'Error Record Submission.');
            }
        }
    }

    public function update_record(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'name' => 'required',
            'phone' => 'required',
            'address' => 'required',
            'postal_code' => 'required',
            'state' => 'required',
            'city' => 'required',
            'mls_number' => 'required',
            'commission' => 'required',
            'type' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }
        $rec = Record::findOrFail($request->id);
        $rec->name = $request->name;
        $rec->phone = $request->phone;
        $rec->address = $request->address;
        $rec->postal_code = $request->postal_code;
        $rec->state = $request->state;
        $rec->city = $request->city;
        $rec->mls_number = $request->mls_number;
        $rec->commission = $request->commission;
        $rec->type = $request->type;
        $rec->status = $request->status;
        $record = $rec->update();
        if ($record) {
            return redirect()->route('manage_records_list')->with('success', 'Record Updated Successfully.');
        } else {
            return back()->withInput()->with('error', 'Record Not Updated.');
        }
    }


    public function subscription()
    {
        $subscriptions = Subscription::all();
        return view("website.subscription", compact('subscriptions'));
    }

    public function checkout($slug)
    {
        if (Auth::check() && Auth::user()->type == "user") {
            $subscription = Subscription::where('slug', $slug)->first();
            return view("website.checkout", compact('subscription'));
        } else {
            return redirect()->route('login')->with('error', 'Please login first.');
        }
    }

    public function searchrecord(Request $request)
    {
        $query = Record::query();
        if(isset($request->mls_number) && !empty($request->mls_number))
        {
            $query->where('mls_number',$request->mls_number);
        }
        if(isset($request->address) && !empty($request->address))
        {
            $query->where('address', 'like', '%' . $request->address . '%');
        }
        if((isset($request->mls_number) && !empty($request->mls_number)) || (isset($request->address) && !empty($request->address)))
        {
            $records = $query->get();
        }
        else
        {
            $records = array();
        }
        return view("website.searchrecord",compact('records','request'));
    }

    public function faq()
    {
        return view("website.faq");
    }

    public function about()
    {
        return view("website.about");
    }

    public function buyer_agent()
    {
        return view("website.buyer_agent");
    }

    public function listing_agent()
    {
        return view("website.listing_agent");
    }

    public function edit_record($id)
    {
        $record = Record::findOrFail(decrypt($id));
        return view("website.edit_record", compact('record'));
    }

}
