@extends('admin.layout.master')

@section('title')
    Users List
@endsection

<link rel="stylesheet" href="{{ URL::asset('admin/assets/vendors/datatables.net-bs5/dataTables.bootstrap5.css') }}">

@section('content')

    <div class="page-content">

        <nav class="page-breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="{{ route('admin./') }}">Home</a></li>
                <li class="breadcrumb-item active" aria-current="page">Users List</li>
            </ol>
        </nav>

        <div class="row">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-body">
                        <div class="row mb-5">
                            <div class="col-md-12"><h6 class="card-title">Users List</h6></div>
                        </div>
                        <div class="table-responsive">
                            <table id="dataTableExample" class="table">
                                <thead>
                                <tr>
                                    <th>Id</th>
                                    <th>Name</th>
                                    <th>Email</th>
                                    <th>Phone</th>
                                    <th>Email Status</th>
                                    <th>Account Status</th>
                                    <th>Edit</th>
                                    <th>Delete</th>
                                </tr>
                                </thead>
                                <tbody>
                                @forelse($users as $u=>$user)
                                    <tr>
                                        <td>{{ $u+1 }}</td>
                                        <td>{{ ($user->name) ? $user->name : '--' }}</td>
                                        <td>{{ ($user->email) ? $user->email : '--' }}</td>
                                        <td>{{ ($user->phone) ? $user->phone : '--' }}</td>
                                        <td>
                                            @if($user->email_verification=="1")
                                                <a href=""
                                                   onclick="return(confirm('Are you sure to make this user email status unverified ?'))">
                                                    <strong style="color: green">Verified</strong>
                                                </a>
                                            @else
                                                <a href=""
                                                   onclick="return(confirm('Are you sure to make this user email status unverified ?'))">
                                                    <strong style="color: red">Unverified</strong>
                                                </a>
                                            @endif
                                        </td>
                                        <td>
                                            @if($user->status=="active")
                                                <a href=""
                                                   onclick="return(confirm('Are you sure to make this user inactive ?'))">
                                                    <strong style="color: green">Active</strong>
                                                </a>
                                            @else
                                                <a href=""
                                                   onclick="return(confirm('Are you sure to make this user active ?'))">
                                                    <strong style="color: red">Inactive/Blocked</strong>
                                                </a>
                                            @endif
                                        </td>
                                        <td>
                                            <a data-bs-toggle="modal"
                                               data-bs-target="#UpdateTeam{{ $user->id }}"
                                               class="btn btn-info btn-icon">
                                                <i data-feather="edit"></i>
                                            </a>
                                        </td>
                                        <td>
                                            <a href="{{ route('admin.deleted_user',[encrypt($user->id)]) }}"
                                               onclick="return(confirm('Are you sure to delete this user permanently ?'))"
                                               class="btn btn-danger">
                                                <i data-feather="trash"></i>
                                            </a>
                                        </td>
                                    </tr>

                                    <div class="modal fade" id="UpdateTeam{{ $user->id }}" tabindex="-1"
                                         aria-labelledby="exampleModalLabel" aria-hidden="true">
                                        <div class="modal-dialog modal-lg">
                                            <div class="modal-content">
                                                <div class="modal-header bg-dark">
                                                    <h5 class="modal-title text-white" id="exampleModalLabel">Edit
                                                        User</h5>
                                                    <button type="button" class="btn-close" data-bs-dismiss="modal"
                                                            aria-label="btn-close"></button>
                                                </div>
                                                <div class="modal-body">
                                                    <div class="container">
                                                        <form action="{{ route('admin.update_user') }}" method="post"
                                                              enctype="multipart/form-data" class="MyForm">
                                                            @csrf
                                                            <input type="hidden" name="id" value="{{ $user->id }}">
                                                            <div class="row">
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Name </label>
                                                                        <input type="text" name="name"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput"
                                                                               required="" placeholder="Name . . . "
                                                                               value="{{ ($user->name) ? $user->name : '' }}">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Email </label>
                                                                        <input type="email" name="email"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput"
                                                                               required="" placeholder="Email . . . "
                                                                               value="{{ ($user->email) ? $user->email : '' }}">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Phone </label>
                                                                        <input type="text" name="phone"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput"
                                                                               placeholder="Phone . . . "
                                                                               value="{{ ($user->phone) ? $user->phone : '' }}">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Password </label>
                                                                        <input type="password" name="password"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput"
                                                                               minlength="8"
                                                                               placeholder="Password . . . "
                                                                               value="">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Email Status </label>
                                                                        <select name="email_verification"
                                                                                class="form-control MyInput" required>
                                                                            <option value="1"
                                                                                    @if($user->email_verification=="1") selected @endif>
                                                                                Active
                                                                            </option>
                                                                            <option value="0"
                                                                                    @if($user->email_verification=="0") selected @endif>
                                                                                Inactive
                                                                            </option>
                                                                        </select>
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Account Status </label>
                                                                        <select name="status"
                                                                                class="form-control MyInput" required>
                                                                            <option value="active"
                                                                                    @if($user->status=="active") selected @endif>
                                                                                active
                                                                            </option>
                                                                            <option value="inactive"
                                                                                    @if($user->status=="inactive") selected @endif>
                                                                                inactive
                                                                            </option>
                                                                        </select>
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-12 mt-3 text-center">
                                                                    <button class="btn btn-dark MyButton" type="submit">
                                                                        Save
                                                                    </button>
                                                                </div>
                                                            </div>
                                                        </form>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                @empty
                                @endforelse
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
@section('script')

    <script src="{{ URL::asset('admin/assets/vendors/datatables.net/jquery.dataTables.js') }}"></script>
    <script src="{{ URL::asset('admin/assets/vendors/datatables.net-bs5/dataTables.bootstrap5.js') }}"></script>
    <script src="{{ URL::asset('admin/assets/js/data-table.js') }}"></script>

@endsection
